@@ -3,17 +3,18 @@ package args
 import (
 	"strings"
 
+	"github.com/go-task/task/v3"
 	"github.com/go-task/task/v3/taskfile/ast"
 )
 
 // Parse parses command line argument: tasks and global variables
-func Parse(args ...string) ([]*ast.Call, *ast.Vars) {
-	calls := []*ast.Call{}
+func Parse(args ...string) ([]*task.Call, *ast.Vars) {
+	calls := []*task.Call{}
 	globals := ast.NewVars()
 
 	for _, arg := range args {
 		if !strings.Contains(arg, "=") {
-			calls = append(calls, &ast.Call{Task: arg})
+			calls = append(calls, &task.Call{Task: arg})
 			continue
 		}
 
