@@ -15,13 +15,12 @@ import (
 	"github.com/go-task/task/v3/errors"
 	"github.com/go-task/task/v3/internal/fingerprint"
 	"github.com/go-task/task/v3/internal/logger"
-	"github.com/go-task/task/v3/taskfile/ast"
 )
 
 const defaultWatchInterval = 5 * time.Second
 
 // watchTasks start watching the given tasks
-func (e *Executor) watchTasks(calls ...*ast.Call) error {
+func (e *Executor) watchTasks(calls ...*Call) error {
 	tasks := make([]string, len(calls))
 	for i, c := range calls {
 		tasks[i] = c.Task
@@ -119,24 +118,24 @@ func closeOnInterrupt(w *watcher.Watcher) {
 	}()
 }
 
-func (e *Executor) registerWatchedFiles(w *watcher.Watcher, calls ...*ast.Call) error {
+func (e *Executor) registerWatchedFiles(w *watcher.Watcher, calls ...*Call) error {
 	watchedFiles := w.WatchedFiles()
 
-	var registerTaskFiles func(*ast.Call) error
-	registerTaskFiles = func(c *ast.Call) error {
+	var registerTaskFiles func(*Call) error
+	registerTaskFiles = func(c *Call) error {
 		task, err := e.CompiledTask(c)
 		if err != nil {
 			return err
 		}
 
 		for _, d := range task.Deps {
-			if err := registerTaskFiles(&ast.Call{Task: d.Task, Vars: d.Vars}); err != nil {
+			if err := registerTaskFiles(&Call{Task: d.Task, Vars: d.Vars}); err != nil {
 				return err
 			}
 		}
 		for _, c := range task.Cmds {
 			if c.Task != "" {
-				if err := registerTaskFiles(&ast.Call{Task: c.Task, Vars: c.Vars}); err != nil {
+				if err := registerTaskFiles(&Call{Task: c.Task, Vars: c.Vars}); err != nil {
 					return err
 				}
 			}
@@ -157,7 +156,7 @@ func (e *Executor) registerWatchedFiles(w *watcher.Watcher, calls ...*ast.Call)
 				if err != nil {
 					return err
 				}
-				if shouldIgnoreFile(absFile) {
+				if ShouldIgnoreFile(absFile) {
 					continue
 				}
 				if _, ok := watchedFiles[absFile]; ok {
@@ -180,7 +179,7 @@ func (e *Executor) registerWatchedFiles(w *watcher.Watcher, calls ...*ast.Call)
 	return nil
 }
 
-func shouldIgnoreFile(path string) bool {
+func ShouldIgnoreFile(path string) bool {
 	ignorePaths := []string{
 		"/.task",
 		"/.git",
